@@ -36,7 +36,7 @@ class CvsService_stub;
 
 class DiffDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
