@@ -51,7 +51,7 @@ public:
 
 class LogDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
