@@ -132,7 +132,7 @@ CatalogManagerView::CatalogManagerView(KBabel::Project::Ptr project, TQWidget* p
    _dictBox->hide();
 
    _updateTimer = new TQTimer(this);
-   connect(_updateTimer,TQT_SIGNAL(timeout()),this,TQT_SLOT(checkUpdate()));
+   connect(_updateTimer,TQ_SIGNAL(timeout()),this,TQ_SLOT(checkUpdate()));
 
    addColumn(COLTEXT(COL_NAME));
    addColumn(COLTEXT(COL_MARKER),25);
@@ -154,21 +154,21 @@ CatalogManagerView::CatalogManagerView(KBabel::Project::Ptr project, TQWidget* p
 
    if(KContextMenuManager::showOnButtonPress())
    {
-      connect(this,TQT_SIGNAL(rightButtonPressed(TQListViewItem*,const TQPoint &, int))
-           ,this, TQT_SLOT(showContentsMenu(TQListViewItem*,const TQPoint &, int)));
+      connect(this,TQ_SIGNAL(rightButtonPressed(TQListViewItem*,const TQPoint &, int))
+           ,this, TQ_SLOT(showContentsMenu(TQListViewItem*,const TQPoint &, int)));
    }
    else
    {
-      connect(this,TQT_SIGNAL(rightButtonClicked(TQListViewItem*,const TQPoint &, int))
-           ,this, TQT_SLOT(showContentsMenu(TQListViewItem*,const TQPoint &, int)));
+      connect(this,TQ_SIGNAL(rightButtonClicked(TQListViewItem*,const TQPoint &, int))
+           ,this, TQ_SLOT(showContentsMenu(TQListViewItem*,const TQPoint &, int)));
    }
-   connect(this, TQT_SIGNAL(returnPressed(TQListViewItem*))
-           ,this, TQT_SLOT(activateItem(TQListViewItem*)));
-   connect(this, TQT_SIGNAL(doubleClicked(TQListViewItem*))
-           ,this, TQT_SLOT(activateItem(TQListViewItem*)));
-   connect(this,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(checkSelected()));
-   connect( this, TQT_SIGNAL( clicked(TQListViewItem *, const TQPoint &, int)),
-    	   this, TQT_SLOT( columnClicked(TQListViewItem *, const TQPoint &, int)));
+   connect(this, TQ_SIGNAL(returnPressed(TQListViewItem*))
+           ,this, TQ_SLOT(activateItem(TQListViewItem*)));
+   connect(this, TQ_SIGNAL(doubleClicked(TQListViewItem*))
+           ,this, TQ_SLOT(activateItem(TQListViewItem*)));
+   connect(this,TQ_SIGNAL(selectionChanged()),this,TQ_SLOT(checkSelected()));
+   connect( this, TQ_SIGNAL( clicked(TQListViewItem *, const TQPoint &, int)),
+    	   this, TQ_SLOT( columnClicked(TQListViewItem *, const TQPoint &, int)));
 
    _dirCommandsMenu = 0;
    _fileCommandsMenu = 0;
@@ -189,7 +189,7 @@ CatalogManagerView::CatalogManagerView(KBabel::Project::Ptr project, TQWidget* p
 
    _logWindow->setMainWidget(_logView);
 
-   connect(_logWindow,TQT_SIGNAL(user1Clicked()),_logView,TQT_SLOT(clear()));
+   connect(_logWindow,TQ_SIGNAL(user1Clicked()),_logView,TQ_SLOT(clear()));
 
    TQWhatsThis::add(this,i18n("<qt><p><b>Catalog Manager</b></p>\n"
 "<p>The Catalog Manager merges two folders into one tree and displays all\n"
@@ -205,21 +205,21 @@ CatalogManagerView::CatalogManagerView(KBabel::Project::Ptr project, TQWidget* p
 
    // CVS
    cvshandler = new CVSHandler( );
-   connect( cvshandler, TQT_SIGNAL( signalIsPORepository( bool ) ),
-            this, TQT_SLOT( slotValidPOCVSRepository( bool ) ) );
-   connect( cvshandler, TQT_SIGNAL( signalIsPOTRepository( bool ) ),
-            this, TQT_SLOT( slotValidPOTCVSRepository( bool ) ) );
-   connect( cvshandler, TQT_SIGNAL( signalFilesCommitted( const TQStringList& ) ),
-            this, TQT_SLOT( updateFiles( const TQStringList& ) ) );
+   connect( cvshandler, TQ_SIGNAL( signalIsPORepository( bool ) ),
+            this, TQ_SLOT( slotValidPOCVSRepository( bool ) ) );
+   connect( cvshandler, TQ_SIGNAL( signalIsPOTRepository( bool ) ),
+            this, TQ_SLOT( slotValidPOTCVSRepository( bool ) ) );
+   connect( cvshandler, TQ_SIGNAL( signalFilesCommitted( const TQStringList& ) ),
+            this, TQ_SLOT( updateFiles( const TQStringList& ) ) );
 
    // SVN
    svnhandler = new SVNHandler( );
-   connect( svnhandler, TQT_SIGNAL( signalIsPORepository( bool ) ),
-            this, TQT_SLOT( slotValidPOSVNRepository( bool ) ) );
-   connect( svnhandler, TQT_SIGNAL( signalIsPOTRepository( bool ) ),
-            this, TQT_SLOT( slotValidPOTSVNRepository( bool ) ) );
-   connect( svnhandler, TQT_SIGNAL( signalFilesCommitted( const TQStringList& ) ),
-            this, TQT_SLOT( updateFiles( const TQStringList& ) ) );
+   connect( svnhandler, TQ_SIGNAL( signalIsPORepository( bool ) ),
+            this, TQ_SLOT( slotValidPOSVNRepository( bool ) ) );
+   connect( svnhandler, TQ_SIGNAL( signalIsPOTRepository( bool ) ),
+            this, TQ_SLOT( slotValidPOTSVNRepository( bool ) ) );
+   connect( svnhandler, TQ_SIGNAL( signalFilesCommitted( const TQStringList& ) ),
+            this, TQ_SLOT( updateFiles( const TQStringList& ) ) );
 
    TDEConfig *config = TDEGlobal::config();
    restoreView(config);
@@ -284,13 +284,13 @@ void CatalogManagerView::setRMBMenuDir( TQPopupMenu *m )
 void CatalogManagerView::setDirCommandsMenu( TQPopupMenu *m )
 {
     _dirCommandsMenu = m;
-    connect(_dirCommandsMenu,TQT_SIGNAL(activated(int)),this,TQT_SLOT(slotDirCommand(int)));
+    connect(_dirCommandsMenu,TQ_SIGNAL(activated(int)),this,TQ_SLOT(slotDirCommand(int)));
 }
 
 void CatalogManagerView::setFileCommandsMenu( TQPopupMenu *m )
 {
     _fileCommandsMenu = m;
-    connect(_fileCommandsMenu,TQT_SIGNAL(activated(int)),this,TQT_SLOT(slotFileCommand(int)));
+    connect(_fileCommandsMenu,TQ_SIGNAL(activated(int)),this,TQ_SLOT(slotFileCommand(int)));
 }
 
 void CatalogManagerView::checkUpdate()
@@ -353,12 +353,12 @@ void CatalogManagerView::clear()
       delete _dirWatch;
 
    _dirWatch= new KDirWatch();
-   connect(_dirWatch,TQT_SIGNAL(deleted(const TQString&)),this
-				   ,TQT_SLOT(directoryDeleted(const TQString&)));
-   connect(_dirWatch,TQT_SIGNAL(dirty(const TQString&)),this
-				   ,TQT_SLOT(directoryChanged(const TQString&)));
-   connect(_dirWatch,TQT_SIGNAL(created(const TQString&)),this
-				   ,TQT_SLOT(directoryChanged(const TQString&)));
+   connect(_dirWatch,TQ_SIGNAL(deleted(const TQString&)),this
+				   ,TQ_SLOT(directoryDeleted(const TQString&)));
+   connect(_dirWatch,TQ_SIGNAL(dirty(const TQString&)),this
+				   ,TQ_SLOT(directoryChanged(const TQString&)));
+   connect(_dirWatch,TQ_SIGNAL(created(const TQString&)),this
+				   ,TQ_SLOT(directoryChanged(const TQString&)));
 
    _dirList.clear();
    _fileList.clear();
@@ -1620,12 +1620,12 @@ void CatalogManagerView::slotDirCommand(int index)
       TDEProcess* proc = new KShellProcess();
       _pendingProcesses.append(proc);
 
-      connect( proc,TQT_SIGNAL( processExited(TDEProcess *) ), this
-               ,TQT_SLOT( processEnded(TDEProcess*) ) );
-      connect( proc,TQT_SIGNAL( receivedStdout(TDEProcess*,char*,int) ), this
-               ,TQT_SLOT( showOutput(TDEProcess*,char*,int) ) );
-      connect( proc,TQT_SIGNAL( receivedStderr(TDEProcess*,char*,int) ), this
-               ,TQT_SLOT( showOutput(TDEProcess*,char*,int) ) );
+      connect( proc,TQ_SIGNAL( processExited(TDEProcess *) ), this
+               ,TQ_SLOT( processEnded(TDEProcess*) ) );
+      connect( proc,TQ_SIGNAL( receivedStdout(TDEProcess*,char*,int) ), this
+               ,TQ_SLOT( showOutput(TDEProcess*,char*,int) ) );
+      connect( proc,TQ_SIGNAL( receivedStderr(TDEProcess*,char*,int) ), this
+               ,TQ_SLOT( showOutput(TDEProcess*,char*,int) ) );
 
       *proc << "cd" << item->poFile() << ";" << cmd;
       proc->start(TDEProcess::NotifyOnExit,TDEProcess::AllOutput);
@@ -1653,12 +1653,12 @@ void CatalogManagerView::slotFileCommand(int index)
       TDEProcess* proc = new KShellProcess();
       _pendingProcesses.append(proc);
 
-      connect( proc,TQT_SIGNAL( processExited(TDEProcess *) ), this
-               ,TQT_SLOT( processEnded(TDEProcess*) ) );
-      connect( proc,TQT_SIGNAL( receivedStdout(TDEProcess*,char*,int) ), this
-               ,TQT_SLOT( showOutput(TDEProcess*,char*,int) ) );
-      connect( proc,TQT_SIGNAL( receivedStderr(TDEProcess*,char*,int) ), this
-               ,TQT_SLOT( showOutput(TDEProcess*,char*,int) ) );
+      connect( proc,TQ_SIGNAL( processExited(TDEProcess *) ), this
+               ,TQ_SLOT( processEnded(TDEProcess*) ) );
+      connect( proc,TQ_SIGNAL( receivedStdout(TDEProcess*,char*,int) ), this
+               ,TQ_SLOT( showOutput(TDEProcess*,char*,int) ) );
+      connect( proc,TQ_SIGNAL( receivedStderr(TDEProcess*,char*,int) ), this
+               ,TQ_SLOT( showOutput(TDEProcess*,char*,int) ) );
 
       *proc << "cd" << parent->poFile() << ";" << cmd;
       proc->start(TDEProcess::NotifyOnExit,TDEProcess::AllOutput);
@@ -1741,7 +1741,7 @@ void CatalogManagerView::updateAfterSave(TQString fileWithPath, PoInfo &newInfo)
 void CatalogManagerView::buildTree()
 {
    // in case we were called after settings update
-   disconnect( this, TQT_SIGNAL( updateFinished() ), this, TQT_SLOT(buildTree() ) );
+   disconnect( this, TQ_SIGNAL( updateFinished() ), this, TQ_SLOT(buildTree() ) );
 
    emit signalBuildTree(false); // announce start of building
 
@@ -2444,7 +2444,7 @@ void CatalogManagerView::setSettings(CatManSettings newSettings)
       counter++;
    }
    _dirCommandsMenu->insertSeparator();
-   _dirCommandsMenu->insertItem(i18n("Log Window"),this,TQT_SLOT(showLog()));
+   _dirCommandsMenu->insertItem(i18n("Log Window"),this,TQ_SLOT(showLog()));
 
    _fileCommandsMenu->clear();
    counter=0;
@@ -2455,7 +2455,7 @@ void CatalogManagerView::setSettings(CatManSettings newSettings)
       counter++;
    }
    _fileCommandsMenu->insertSeparator();
-   _fileCommandsMenu->insertItem(i18n("Log Window"),this,TQT_SLOT(showLog()));
+   _fileCommandsMenu->insertItem(i18n("Log Window"),this,TQ_SLOT(showLog()));
 
    const bool pathChanged = (oldSettings.poBaseDir!=_settings.poBaseDir)
            || (oldSettings.potBaseDir!=_settings.potBaseDir);
@@ -2463,10 +2463,10 @@ void CatalogManagerView::setSettings(CatManSettings newSettings)
    if(pathChanged)
    {
       if( !isActive() ) {
-        TQTimer::singleShot(100,this,TQT_SLOT(buildTree()));
+        TQTimer::singleShot(100,this,TQ_SLOT(buildTree()));
       } else {
         stop();
-        connect( this, TQT_SIGNAL( updateFinished() ), this, TQT_SLOT(buildTree() ) );
+        connect( this, TQ_SIGNAL( updateFinished() ), this, TQ_SLOT(buildTree() ) );
       }
    }
 
@@ -2497,7 +2497,7 @@ void CatalogManagerView::hideEvent(TQHideEvent*)
 
 void CatalogManagerView::showEvent(TQShowEvent*)
 {
-   TQTimer::singleShot(1,this,TQT_SLOT(checkUpdate()));
+   TQTimer::singleShot(1,this,TQ_SLOT(checkUpdate()));
 
    pause(false);
 
@@ -2507,7 +2507,7 @@ void CatalogManagerView::showEvent(TQShowEvent*)
 
 void CatalogManagerView::contentsMousePressEvent(TQMouseEvent* event)
 {
-   if(event->button() == Qt::LeftButton)
+   if(event->button() == TQt::LeftButton)
       _pressPos=event->pos();
 
    TQListView::contentsMousePressEvent( event );
@@ -2515,7 +2515,7 @@ void CatalogManagerView::contentsMousePressEvent(TQMouseEvent* event)
 
 void CatalogManagerView::contentsMouseMoveEvent(TQMouseEvent* event)
 {
-   if(event->state() & Qt::LeftButton)
+   if(event->state() & TQt::LeftButton)
    {
       const int delay = TDEGlobalSettings::dndEventDelay();
       if(TQABS( event->pos().x() - _pressPos.x() ) >= delay ||
@@ -3025,8 +3025,8 @@ void CatalogManagerView::validate_internal( const TQStringList& files, const KDa
     if( !_validateDialog )
     {
 	_validateDialog = new ValidateProgressDialog(_settings.ignoreURL, this);
-	connect( _validateDialog, TQT_SIGNAL( errorDoubleClicked(const TQString,const int)),
-	    this, TQT_SLOT(showError( const TQString, const int )));
+	connect( _validateDialog, TQ_SIGNAL( errorDoubleClicked(const TQString,const int)),
+	    this, TQ_SLOT(showError( const TQString, const int )));
     }
 
     _markAsFuzzy = _validateOptions->markAsFuzzy->isChecked();
@@ -3129,4 +3129,3 @@ void CatalogManagerView::toggleColumn( uint column, bool show )
 }
 
 #include "catalogmanagerview.moc"
-// kate: space-indent on; indent-width 4; replace-tabs on;
