@@ -45,7 +45,7 @@ class ProjectStep2;
 
 namespace KBabel {
 
-class KDE_EXPORT ProjectWizard : public KWizard
+class TDE_EXPORT ProjectWizard : public KWizard
 {
     TQ_OBJECT
   
