@@ -91,8 +91,8 @@ SearchEngine (parent, name)
     searching = false;
     stopNow = false;
 
-    norm = false;		// Normalize white space = FALSE
-    comm = true;		// Remove Comments = TRUE
+    norm = false;		// Normalize white space = false
+    comm = true;		// Remove Comments = true
 
 }
 
