@@ -1,6 +1,6 @@
 
 #include <tdelocale.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeaboutdata.h>
 #include <kdebug.h>
 
