@@ -174,7 +174,7 @@ DataBaseInterface::MainEntry DataBaseInterface::get(const TQString& query,Search
     //  kdDebug(0) << "MAINDB->GET returned: " << r << endl;
     if(counter%5==0) kapp->processEvents(100);
     //  kdDebug(0) << "events processed" << endl;
-    return tqMakePair(k,d);
+    return qMakePair(k,d);
     
 }
 
@@ -727,7 +727,7 @@ DataBaseInterface::MainEntry DataBaseInterface::getSentence( const TQString & qu
     DBItemMainData d;
     sentence->get(&k,&d);
     if(counter%5==0) kapp->processEvents(100);
-    return tqMakePair(k,d);
+    return qMakePair(k,d);
     
 }
 
