@@ -19,7 +19,7 @@ class TQTextStream;
 
 class Smtp : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
