@@ -57,9 +57,9 @@ CentralWidget::CentralWidget( const TQCString &initialPackage,
                        KDialog::spacingHint() ) )->setAutoAdd( true );
 
     // Create TQSplitter children
-    m_vertSplitter = new TQSplitter( Qt::Vertical, this );
+    m_vertSplitter = new TQSplitter( TQt::Vertical, this );
     m_listPane     = new CWBugListContainer( m_vertSplitter );
-    m_horSplitter  = new TQSplitter( Qt::Horizontal,m_vertSplitter );
+    m_horSplitter  = new TQSplitter( TQt::Horizontal,m_vertSplitter );
 // The search pane isn't used. Should we remove the code?
     m_searchPane   = new CWSearchWidget( m_horSplitter );
     m_bugPane      = new CWBugDetailsContainer( m_horSplitter );
@@ -71,51 +71,51 @@ CentralWidget::CentralWidget( const TQCString &initialPackage,
                                                     TQSizePolicy::Minimum ) );
     m_horSplitter->setResizeMode( m_searchPane, TQSplitter::FollowSizeHint );
 
-    connect( m_listPane, TQT_SIGNAL( resetProgressBar() ),
-             TQT_SIGNAL( resetProgressBar() ) );
-    connect( m_bugPane, TQT_SIGNAL( resetProgressBar() ),
-             TQT_SIGNAL( resetProgressBar() ) );
+    connect( m_listPane, TQ_SIGNAL( resetProgressBar() ),
+             TQ_SIGNAL( resetProgressBar() ) );
+    connect( m_bugPane, TQ_SIGNAL( resetProgressBar() ),
+             TQ_SIGNAL( resetProgressBar() ) );
 
     // Start the proper jobs for loading the package lists
     connect( BugSystem::self(),
-             TQT_SIGNAL( packageListAvailable( const Package::List & ) ),
-             TQT_SLOT( updatePackageList( const Package::List & ) ) );
+             TQ_SIGNAL( packageListAvailable( const Package::List & ) ),
+             TQ_SLOT( updatePackageList( const Package::List & ) ) );
     connect( BugSystem::self(),
-             TQT_SIGNAL( bugListAvailable( const Package &, const TQString &, const Bug::List & ) ),
-             TQT_SLOT( updateBugList( const Package &, const TQString &, const Bug::List & ) ) );
+             TQ_SIGNAL( bugListAvailable( const Package &, const TQString &, const Bug::List & ) ),
+             TQ_SLOT( updateBugList( const Package &, const TQString &, const Bug::List & ) ) );
     connect( BugSystem::self(),
-             TQT_SIGNAL( bugListAvailable( const TQString &, const Bug::List & ) ),
-             TQT_SLOT( updateBugList( const TQString &, const Bug::List & ) ) );
+             TQ_SIGNAL( bugListAvailable( const TQString &, const Bug::List & ) ),
+             TQ_SLOT( updateBugList( const TQString &, const Bug::List & ) ) );
     connect( BugSystem::self(),
-             TQT_SIGNAL( bugDetailsAvailable( const Bug &, const BugDetails & ) ),
-             TQT_SLOT( updateBugDetails( const Bug &, const BugDetails & ) ) );
+             TQ_SIGNAL( bugDetailsAvailable( const Bug &, const BugDetails & ) ),
+             TQ_SLOT( updateBugDetails( const Bug &, const BugDetails & ) ) );
 
-    connect( BugSystem::self(), TQT_SIGNAL( loadingError( const TQString & ) ),
-             TQT_SLOT( showLoadingError( const TQString & ) ) );
+    connect( BugSystem::self(), TQ_SIGNAL( loadingError( const TQString & ) ),
+             TQ_SLOT( showLoadingError( const TQString & ) ) );
 
-    connect( m_bugPane, TQT_SIGNAL( signalCloseBug() ), TQT_SLOT( closeBug() ) );
-    connect( m_bugPane, TQT_SIGNAL( signalCloseBugSilently() ), TQT_SLOT( closeBugSilently() ) );
-    connect( m_bugPane, TQT_SIGNAL( signalReopenBug() ), TQT_SLOT( reopenBug() ) );
-    connect( m_bugPane, TQT_SIGNAL( signalReassignBug() ), TQT_SLOT( reassignBug() ) );
-    connect( m_bugPane, TQT_SIGNAL( signalTitleBug() ), TQT_SLOT( titleBug() ) );
-    connect( m_bugPane, TQT_SIGNAL( signalSeverityBug() ), TQT_SLOT( severityBug() ) );
-    connect( m_bugPane, TQT_SIGNAL( signalReplyBug() ), TQT_SLOT( replyBug() ) );
-    connect( m_bugPane, TQT_SIGNAL( signalReplyPrivateBug() ), TQT_SLOT( replyPrivateBug() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalCloseBug() ), TQ_SLOT( closeBug() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalCloseBugSilently() ), TQ_SLOT( closeBugSilently() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalReopenBug() ), TQ_SLOT( reopenBug() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalReassignBug() ), TQ_SLOT( reassignBug() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalTitleBug() ), TQ_SLOT( titleBug() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalSeverityBug() ), TQ_SLOT( severityBug() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalReplyBug() ), TQ_SLOT( replyBug() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalReplyPrivateBug() ), TQ_SLOT( replyPrivateBug() ) );
 
-    connect( m_bugPane, TQT_SIGNAL( signalClearCommand() ), TQT_SLOT( clearCommand() ) );
+    connect( m_bugPane, TQ_SIGNAL( signalClearCommand() ), TQ_SLOT( clearCommand() ) );
 
     // Add the selection slots for the listviews
     connect( m_searchPane->m_searchPackages,
-             TQT_SIGNAL( activated( const TQString & ) ),
-             TQT_SLOT( slotRetrieveBugList( const TQString & ) ) );
+             TQ_SIGNAL( activated( const TQString & ) ),
+             TQ_SLOT( slotRetrieveBugList( const TQString & ) ) );
 
-    connect( m_listPane, TQT_SIGNAL( executed( const Bug & ) ),
-             TQT_SLOT( slotRetrieveBugDetails( const Bug & ) ) );
-    connect( m_listPane, TQT_SIGNAL( currentChanged( const Bug & ) ),
-             TQT_SLOT( slotSetActiveBug( const Bug & ) ) );
+    connect( m_listPane, TQ_SIGNAL( executed( const Bug & ) ),
+             TQ_SLOT( slotRetrieveBugDetails( const Bug & ) ) );
+    connect( m_listPane, TQ_SIGNAL( currentChanged( const Bug & ) ),
+             TQ_SLOT( slotSetActiveBug( const Bug & ) ) );
 
-    connect( m_listPane, TQT_SIGNAL( searchPackage() ), TQT_SIGNAL( searchPackage() ) );
-    connect( m_bugPane, TQT_SIGNAL( searchBugNumber() ), TQT_SIGNAL( searchBugNumber() ) );
+    connect( m_listPane, TQ_SIGNAL( searchPackage() ), TQ_SIGNAL( searchPackage() ) );
+    connect( m_bugPane, TQ_SIGNAL( searchBugNumber() ), TQ_SIGNAL( searchBugNumber() ) );
 
     m_bLoadingAllBugs = false;
 
@@ -503,5 +503,3 @@ CWBugDetails *CentralWidget::bugDetailsWidget()
 }
 
 #include "centralwidget.moc"
-
-/* vim: set et ts=4 sw=4 softtabstop=4: */
