@@ -12,7 +12,7 @@
 #include <tqvaluelist.h>
 #include <stdlib.h>
 #include <tdetempfile.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <kstandarddirs.h>
 #include <tdecmdlineargs.h>
 #include <kprocess.h>
