@@ -29,7 +29,7 @@ class TDEConfig;
 
 class SettingsBase : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	SettingsBase( TQWidget* parent );
