@@ -28,7 +28,7 @@
 #include <kdebug.h>
 #include <kdialogbase.h>
 #include <kiconloader.h>
-#include <kinstance.h>
+#include <tdeinstance.h>
 #include <tdeio/netaccess.h>
 #include <tdelistview.h>
 #include <tdeparts/genericfactory.h>
