@@ -136,19 +136,19 @@ InstrView::InstrView(TraceItemView* parentView,
   setColumnAlignment(2, TQt::AlignRight);
 
   connect(this,
-          TQT_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint &, int)),
-          TQT_SLOT(context(TQListViewItem*, const TQPoint &, int)));
+          TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint &, int)),
+          TQ_SLOT(context(TQListViewItem*, const TQPoint &, int)));
 
-  connect(this, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-          TQT_SLOT(selectedSlot(TQListViewItem*)));
+  connect(this, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+          TQ_SLOT(selectedSlot(TQListViewItem*)));
 
   connect(this,
-          TQT_SIGNAL(doubleClicked(TQListViewItem*)),
-          TQT_SLOT(activatedSlot(TQListViewItem*)));
+          TQ_SIGNAL(doubleClicked(TQListViewItem*)),
+          TQ_SLOT(activatedSlot(TQListViewItem*)));
 
   connect(this,
-          TQT_SIGNAL(returnPressed(TQListViewItem*)),
-          TQT_SLOT(activatedSlot(TQListViewItem*)));
+          TQ_SIGNAL(returnPressed(TQListViewItem*)),
+          TQ_SLOT(activatedSlot(TQListViewItem*)));
 
   TQWhatsThis::add( this, whatsThis());
 }
