@@ -554,7 +554,7 @@ void ClassifierWidget::draw(TQPainter & p, int offsetX, int offsetY) {
     if ( tlist.count() > 0 ) {
         UMLWidget::setPen(p);
         TQPen pen = p.pen();
-        pen.setStyle(Qt::DotLine);
+        pen.setStyle(TQt::DotLine);
         p.setPen(pen);
         p.drawRect( offsetX + width() - templatesBoxSize.width(), offsetY,
                     templatesBoxSize.width(), templatesBoxSize.height() );
