@@ -39,7 +39,7 @@
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.trinitydesktop.org
  */
 class AssocPage : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
