@@ -85,8 +85,8 @@ void LinePath::setAssociation(AssociationWidget * association ) {
     if( getAssocType() == Uml::at_Coll_Message )
         setupParallelLine();
     UMLView * view =  (UMLView *)m_pAssociation -> parent();
-    connect( view, TQT_SIGNAL( sigColorChanged( Uml::IDType ) ), this, TQT_SLOT( slotLineColorChanged( Uml::IDType ) ) );
-    connect( view, TQT_SIGNAL( sigLineWidthChanged( Uml::IDType ) ), this, TQT_SLOT( slotLineWidthChanged( Uml::IDType ) ) );
+    connect( view, TQ_SIGNAL( sigColorChanged( Uml::IDType ) ), this, TQ_SLOT( slotLineColorChanged( Uml::IDType ) ) );
+    connect( view, TQ_SIGNAL( sigLineWidthChanged( Uml::IDType ) ), this, TQ_SLOT( slotLineWidthChanged( Uml::IDType ) ) );
 }
 
 TQPoint LinePath::getPoint( int pointIndex ) {
@@ -849,8 +849,8 @@ void LinePath::cleanup() {
     if( m_pAssociation ) {
         UMLView * view =  (UMLView *)m_pAssociation -> parent();
         if(view) {
-            disconnect( view, TQT_SIGNAL( sigColorChanged( Uml::IDType ) ), this, TQT_SLOT( slotLineColorChanged( Uml::IDType ) ) );
-            disconnect( view, TQT_SIGNAL( sigLineWidthChanged( Uml::IDType ) ), this, TQT_SLOT( slotLineWidthChanged( Uml::IDType ) ) );
+            disconnect( view, TQ_SIGNAL( sigColorChanged( Uml::IDType ) ), this, TQ_SLOT( slotLineColorChanged( Uml::IDType ) ) );
+            disconnect( view, TQ_SIGNAL( sigLineWidthChanged( Uml::IDType ) ), this, TQ_SLOT( slotLineWidthChanged( Uml::IDType ) ) );
         }
         m_pAssociation = NULL;
     }
