@@ -249,11 +249,11 @@ ListPopupMenu::ListPopupMenu(TQWidget * parent, UMLWidget * object,
         }
 
         if(m_pInsert)
-            connect(m_pInsert, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+            connect(m_pInsert, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
         if(m_pShow)
-            connect(m_pShow, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+            connect(m_pShow, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
         if(m_pColor)
-            connect(m_pColor, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+            connect(m_pColor, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
         return;
     }
 
@@ -437,11 +437,11 @@ ListPopupMenu::ListPopupMenu(TQWidget * parent, UMLWidget * object,
     }//end switch
 
     if(m_pInsert)
-        connect(m_pInsert, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+        connect(m_pInsert, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
     if(m_pShow)
-        connect(m_pShow, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+        connect(m_pShow, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
     if(m_pColor)
-        connect(m_pColor, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+        connect(m_pColor, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
 
     bool bCutState = UMLApp::app() -> getCutCopyState();
     setItemEnabled( mt_Cut, bCutState );
@@ -1321,11 +1321,11 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         setItemEnabled( mt_Paste, UMLApp::app() -> getPasteState() );
     }
     if(m_pInsert)
-        connect(m_pInsert, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+        connect(m_pInsert, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
     if(m_pShow)
-        connect(m_pShow, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+        connect(m_pShow, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
     if(m_pColor)
-        connect(m_pColor, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(activated(int)));
+        connect(m_pColor, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(activated(int)));
 }
 
 void ListPopupMenu::setupDiagramMenu(UMLView* view) {
