@@ -59,9 +59,9 @@ void UMLWidgetController::mousePressEvent(TQMouseEvent *me) {
         return;
     }
 
-    if (me->button() == Qt::LeftButton) {
+    if (me->button() == TQt::LeftButton) {
         m_leftButtonDown = true;
-    } else if (me->button() == Qt::RightButton) {
+    } else if (me->button() == TQt::RightButton) {
         m_rightButtonDown = true;
     } else {
         m_middleButtonDown = true;
@@ -77,7 +77,7 @@ void UMLWidgetController::mousePressEvent(TQMouseEvent *me) {
     if (me->state() == TQt::ShiftButton || me->state() == TQt::ControlButton) {
         m_shiftPressed = true;
 
-        if (me->button() == Qt::LeftButton) {
+        if (me->button() == TQt::LeftButton) {
             m_inMoveArea = true;
         }
 
@@ -92,7 +92,7 @@ void UMLWidgetController::mousePressEvent(TQMouseEvent *me) {
     m_shiftPressed = false;
 
     int count = m_widget->m_pView->getSelectCount(true);
-    if (me->button() == Qt::LeftButton) {
+    if (me->button() == TQt::LeftButton) {
         if (m_widget->m_bSelected && count > 1) {
             //Single selection is made in release event if the widget wasn't moved
             m_inMoveArea = true;
@@ -189,12 +189,12 @@ void UMLWidgetController::mouseMoveEvent(TQMouseEvent* me) {
 }
 
 void UMLWidgetController::mouseReleaseEvent(TQMouseEvent *me) {
-    if (me->button() != Qt::LeftButton && me->button() != Qt::RightButton) {
+    if (me->button() != TQt::LeftButton && me->button() != TQt::RightButton) {
         if (m_middleButtonDown) {
             m_middleButtonDown = false;
             resetSelection();
         }
-    } else if (me->button() == Qt::LeftButton) {
+    } else if (me->button() == TQt::LeftButton) {
         if (m_leftButtonDown) {
             m_leftButtonDown = false;
 
@@ -238,7 +238,7 @@ void UMLWidgetController::mouseReleaseEvent(TQMouseEvent *me) {
                 m_inMoveArea = false;
             }
         }
-    } else if (me->button() == Qt::RightButton) {
+    } else if (me->button() == TQt::RightButton) {
         if (m_rightButtonDown) {
             m_rightButtonDown = false;
             showPopupMenu(me);
@@ -246,11 +246,11 @@ void UMLWidgetController::mouseReleaseEvent(TQMouseEvent *me) {
             //Cancel move/edit
             TQMouseEvent move(TQMouseEvent::MouseMove,
                                 TQPoint(m_oldX + m_pressOffsetX, m_oldY + m_pressOffsetY),
-                                Qt::LeftButton, Qt::NoButton);
+                                TQt::LeftButton, TQt::NoButton);
             mouseMoveEvent(&move);
             TQMouseEvent release(TQMouseEvent::MouseButtonRelease,
                                 TQPoint(m_oldX + m_pressOffsetX, m_oldY + m_pressOffsetY),
-                                Qt::LeftButton, Qt::NoButton);
+                                TQt::LeftButton, TQt::NoButton);
             mouseReleaseEvent(&release);
         }
     }
@@ -267,7 +267,7 @@ void UMLWidgetController::mouseReleaseEvent(TQMouseEvent *me) {
 }
 
 void UMLWidgetController::mouseDoubleClickEvent(TQMouseEvent *me) {
-    if (me->button() != Qt::LeftButton) {
+    if (me->button() != TQt::LeftButton) {
         return;
     }
 
