@@ -28,7 +28,7 @@ class UMLObject;
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.trinitydesktop.org
  */
 class WidgetBase : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
